@@ -65,7 +65,7 @@ def unify_bucket_name_and_key(func: T) -> T:
     def wrapper(*args, **kwargs) -> T:
         bound_args = function_signature.bind(*args, **kwargs)
 
-        def get_key() -> Optional[str]:
+        def get_key() -> str:
             if 'key' in bound_args.arguments:
                 return 'key'
             raise ValueError('Missing key parameter!')
@@ -89,10 +89,13 @@ class OSSHook(BaseHook):
     conn_type = 'oss'
     hook_name = 'OSS'
 
-    def __init__(self, region, oss_conn_id='oss_default', *args, **kwargs) -> None:
+    def __init__(self, region: Optional[str] = None, oss_conn_id='oss_default', *args, **kwargs) -> None:
         self.oss_conn_id = oss_conn_id
         self.oss_conn = self.get_connection(oss_conn_id)
-        self.region = region
+        if region is None:
+            self.region = self.get_default_region()
+        else:
+            self.region = region
         super().__init__(*args, **kwargs)
 
     def get_conn(self) -> "Connection":
@@ -105,9 +108,7 @@ class OSSHook(BaseHook):
         Parses the OSS Url into a bucket name and key.
 
         :param ossurl: The OSS Url to parse.
-        :rtype ossurl: str
         :return: the parsed bucket name and key
-        :rtype: tuple of str
         """
         parsed_url = urlparse(ossurl)
 
@@ -119,15 +120,14 @@ class OSSHook(BaseHook):
 
         return bucket_name, key
 
+    @provide_bucket_name
     @unify_bucket_name_and_key
     def object_exists(self, key: str, bucket_name: Optional[str] = None) -> bool:
         """
         Check if object exists.
 
         :param key: the path of the object
-        :type key: str
         :param bucket_name: the name of the bucket
-        :type bucket_name: str
         :return: True if it exists and False if not.
         :rtype: bool
         """
@@ -143,30 +143,29 @@ class OSSHook(BaseHook):
         Returns a oss2.Bucket object
 
         :param bucket_name: the name of the bucket
-        :type bucket_name: str
         :return: the bucket object to the bucket name.
         :rtype: oss2.api.Bucket
         """
         auth = self.get_credential()
+        assert self.region is not None
         return oss2.Bucket(auth, 'http://oss-' + self.region + '.aliyuncs.com', bucket_name)
 
+    @provide_bucket_name
     @unify_bucket_name_and_key
     def load_string(self, key: str, content: str, bucket_name: Optional[str] = None) -> None:
         """
         Loads a string to OSS
 
         :param key: the path of the object
-        :type key: str
         :param content: str to set as content for the key.
-        :type content: str
         :param bucket_name: the name of the bucket
-        :type bucket_name: str
         """
         try:
             self.get_bucket(bucket_name).put_object(key, content)
         except Exception as e:
             raise AirflowException(f"Errors: {e}")
 
+    @provide_bucket_name
     @unify_bucket_name_and_key
     def upload_local_file(
         self,
@@ -178,17 +177,15 @@ class OSSHook(BaseHook):
         Upload a local file to OSS
 
         :param key: the OSS path of the object
-        :type key: str
         :param file: local file to upload.
-        :type file: str
         :param bucket_name: the name of the bucket
-        :type bucket_name: str
         """
         try:
             self.get_bucket(bucket_name).put_object_from_file(key, file)
         except Exception as e:
             raise AirflowException(f"Errors when upload file: {e}")
 
+    @provide_bucket_name
     @unify_bucket_name_and_key
     def download_file(
         self,
@@ -200,11 +197,8 @@ class OSSHook(BaseHook):
         Download file from OSS
 
         :param key: key of the file-like object to download.
-        :type key: str
         :param local_file: local path + file name to save.
-        :type local_file: str
         :param bucket_name: the name of the bucket
-        :type bucket_name: str
         :return: the file name.
         :rtype: str
         """
@@ -215,6 +209,7 @@ class OSSHook(BaseHook):
             return None
         return local_file
 
+    @provide_bucket_name
     @unify_bucket_name_and_key
     def delete_object(
         self,
@@ -225,9 +220,7 @@ class OSSHook(BaseHook):
         Delete object from OSS
 
         :param key: key of the object to delete.
-        :type key: str
         :param bucket_name: the name of the bucket
-        :type bucket_name: str
         """
         try:
             self.get_bucket(bucket_name).delete_object(key)
@@ -235,6 +228,7 @@ class OSSHook(BaseHook):
             self.log.error(e)
             raise AirflowException(f"Errors when deleting: {key}")
 
+    @provide_bucket_name
     @unify_bucket_name_and_key
     def delete_objects(
         self,
@@ -245,9 +239,7 @@ class OSSHook(BaseHook):
         Delete objects from OSS
 
         :param key: keys list of the objects to delete.
-        :type key: list of str
         :param bucket_name: the name of the bucket
-        :type bucket_name: str
         """
         try:
             self.get_bucket(bucket_name).batch_delete_objects(key)
@@ -264,7 +256,6 @@ class OSSHook(BaseHook):
         Delete bucket from OSS
 
         :param bucket_name: the name of the bucket
-        :type bucket_name: str
         """
         try:
             self.get_bucket(bucket_name).delete_bucket()
@@ -281,7 +272,6 @@ class OSSHook(BaseHook):
         Create bucket
 
         :param bucket_name: the name of the bucket
-        :type bucket_name: str
         """
         try:
             self.get_bucket(bucket_name).create_bucket()
@@ -289,6 +279,73 @@ class OSSHook(BaseHook):
             self.log.error(e)
             raise AirflowException(f"Errors when create bucket: {bucket_name}")
 
+    @provide_bucket_name
+    @unify_bucket_name_and_key
+    def append_string(self, bucket_name: Optional[str], content: str, key: str, pos: int) -> None:
+        """
+        Append string to a remote existing file
+
+        :param bucket_name: the name of the bucket
+        :param content: content to be appended
+        :param key: oss bucket key
+        :param pos: position of the existing file where the content will be appended
+        """
+        self.log.info("Write oss bucket. key: %s, pos: %s", key, pos)
+        try:
+            self.get_bucket(bucket_name).append_object(key, pos, content)
+        except Exception as e:
+            self.log.error(e)
+            raise AirflowException(f"Errors when append string for object: {key}")
+
+    @provide_bucket_name
+    @unify_bucket_name_and_key
+    def read_key(self, bucket_name: Optional[str], key: str) -> str:
+        """
+        Read oss remote object content with the specified key
+
+        :param bucket_name: the name of the bucket
+        :param key: oss bucket key
+        """
+        self.log.info("Read oss key: %s", key)
+        try:
+            return self.get_bucket(bucket_name).get_object(key).read().decode("utf-8")
+        except Exception as e:
+            self.log.error(e)
+            raise AirflowException(f"Errors when read bucket object: {key}")
+
+    @provide_bucket_name
+    @unify_bucket_name_and_key
+    def head_key(self, bucket_name: Optional[str], key: str) -> oss2.models.HeadObjectResult:
+        """
+        Get meta info of the specified remote object
+
+        :param bucket_name: the name of the bucket
+        :param key: oss bucket key
+        """
+        self.log.info("Head Object oss key: %s", key)
+        try:
+            return self.get_bucket(bucket_name).head_object(key)
+        except Exception as e:
+            self.log.error(e)
+            raise AirflowException(f"Errors when head bucket object: {key}")
+
+    @provide_bucket_name
+    @unify_bucket_name_and_key
+    def key_exist(self, bucket_name: Optional[str], key: str) -> bool:
+        """
+        Find out whether the specified key exists in the oss remote storage
+
+        :param bucket_name: the name of the bucket
+        :param key: oss bucket key
+        """
+        # full_path = None
+        self.log.info('Looking up oss bucket %s for bucket key %s ...', bucket_name, key)
+        try:
+            return self.get_bucket(bucket_name).object_exists(key)
+        except Exception as e:
+            self.log.error(e)
+            raise AirflowException(f"Errors when check bucket object existence: {key}")
+
     def get_credential(self) -> oss2.auth.Auth:
         extra_config = self.oss_conn.extra_dejson
         auth_type = extra_config.get('auth_type', None)
@@ -305,3 +362,18 @@ class OSSHook(BaseHook):
             return oss2.Auth(oss_access_key_id, oss_access_key_secret)
         else:
             raise Exception("Unsupported auth_type: " + auth_type)
+
+    def get_default_region(self) -> Optional[str]:
+        extra_config = self.oss_conn.extra_dejson
+        auth_type = extra_config.get('auth_type', None)
+        if not auth_type:
+            raise Exception("No auth_type specified in extra_config. ")
+
+        if auth_type == 'AK':
+            default_region = extra_config.get('region', None)
+            if not default_region:
+                raise Exception("No region is specified for connection: " + self.oss_conn_id)
+        else:
+            raise Exception("Unsupported auth_type: " + auth_type)
+
+        return default_region
