@@ -146,9 +146,7 @@ class CassandraHook(BaseHook, LoggingMixin):
         Creates load balancing policy.
 
         :param policy_name: Name of the policy to use.
-        :type policy_name: str
         :param policy_args: Parameters for the policy.
-        :type policy_args: Dict
         """
         if policy_name == 'DCAwareRoundRobinPolicy':
             local_dc = policy_args.get('local_dc', '')
@@ -184,7 +182,6 @@ class CassandraHook(BaseHook, LoggingMixin):
 
         :param table: Target Cassandra table.
                       Use dot notation to target a specific keyspace.
-        :type table: str
         """
         keyspace = self.keyspace
         if '.' in table:
@@ -198,9 +195,7 @@ class CassandraHook(BaseHook, LoggingMixin):
 
         :param table: Target Cassandra table.
                       Use dot notation to target a specific keyspace.
-        :type table: str
         :param keys: The keys and their values to check the existence.
-        :type keys: dict
         """
         keyspace = self.keyspace
         if '.' in table:
