@@ -15,17 +15,16 @@
 # specific language governing permissions and limitations
 # under the License.
 """Executes task in a Kubernetes POD"""
+import json
+import logging
 import re
+import sys
 import warnings
-from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Optional, Tuple, Type
+from contextlib import AbstractContextManager
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Sequence
 
 from kubernetes.client import CoreV1Api, models as k8s
 
-try:
-    import airflow.utils.yaml as yaml
-except ImportError:
-    import yaml
-
 from airflow.exceptions import AirflowException
 from airflow.kubernetes import kube_client, pod_generator
 from airflow.kubernetes.pod_generator import PodGenerator
@@ -43,15 +42,32 @@ from airflow.providers.cncf.kubernetes.backcompat.backwards_compat_converters im
     convert_volume,
     convert_volume_mount,
 )
-from airflow.providers.cncf.kubernetes.backcompat.pod_runtime_info_env import PodRuntimeInfoEnv
-from airflow.providers.cncf.kubernetes.utils import pod_launcher, xcom_sidecar
-from airflow.utils.helpers import validate_key
-from airflow.utils.state import State
+from airflow.providers.cncf.kubernetes.utils import xcom_sidecar  # type: ignore[attr-defined]
+from airflow.providers.cncf.kubernetes.utils.pod_manager import (
+    PodLaunchFailedException,
+    PodManager,
+    PodPhase,
+    get_container_termination_message,
+)
+from airflow.settings import pod_mutation_hook
+from airflow.utils import yaml
+from airflow.utils.helpers import prune_dict, validate_key
 from airflow.version import version as airflow_version
 
+if sys.version_info >= (3, 8):
+    from functools import cached_property
+else:
+    from cached_property import cached_property
+
 if TYPE_CHECKING:
     import jinja2
 
+    from airflow.utils.context import Context
+
+
+class PodReattachFailure(AirflowException):
+    """When we expect to be able to find a pod but cannot."""
+
 
 class KubernetesPodOperator(BaseOperator):
     """
@@ -68,101 +84,66 @@ class KubernetesPodOperator(BaseOperator):
         simplifies the authorization process.
 
     :param namespace: the namespace to run within kubernetes.
-    :type namespace: str
     :param image: Docker image you wish to launch. Defaults to hub.docker.com,
         but fully qualified URLS will point to custom repositories. (templated)
-    :type image: str
     :param name: name of the pod in which the task will run, will be used (plus a random
-        suffix) to generate a pod id (DNS-1123 subdomain, containing only [a-z0-9.-]).
-    :type name: str
+        suffix if random_name_suffix is True) to generate a pod id (DNS-1123 subdomain,
+        containing only [a-z0-9.-]).
+    :param random_name_suffix: if True, will generate a random suffix.
     :param cmds: entrypoint of the container. (templated)
         The docker images's entrypoint is used if this is not provided.
-    :type cmds: list[str]
     :param arguments: arguments of the entrypoint. (templated)
         The docker image's CMD is used if this is not provided.
-    :type arguments: list[str]
-    :param ports: ports for launched pod.
-    :type ports: list[k8s.V1ContainerPort]
-    :param volume_mounts: volumeMounts for launched pod.
-    :type volume_mounts: list[k8s.V1VolumeMount]
-    :param volumes: volumes for launched pod. Includes ConfigMaps and PersistentVolumes.
-    :type volumes: list[k8s.V1Volume]
+    :param ports: ports for the launched pod.
+    :param volume_mounts: volumeMounts for the launched pod.
+    :param volumes: volumes for the launched pod. Includes ConfigMaps and PersistentVolumes.
     :param env_vars: Environment variables initialized in the container. (templated)
-    :type env_vars: list[k8s.V1EnvVar]
     :param secrets: Kubernetes secrets to inject in the container.
         They can be exposed as environment vars or files in a volume.
-    :type secrets: list[airflow.kubernetes.secret.Secret]
     :param in_cluster: run kubernetes client with in_cluster configuration.
-    :type in_cluster: bool
     :param cluster_context: context that points to kubernetes cluster.
         Ignored when in_cluster is True. If None, current-context is used.
-    :type cluster_context: str
     :param reattach_on_restart: if the scheduler dies while the pod is running, reattach and monitor
-    :type reattach_on_restart: bool
     :param labels: labels to apply to the Pod. (templated)
-    :type labels: dict
     :param startup_timeout_seconds: timeout in seconds to startup the pod.
-    :type startup_timeout_seconds: int
     :param get_logs: get the stdout of the container as logs of the tasks.
-    :type get_logs: bool
     :param image_pull_policy: Specify a policy to cache or always pull an image.
-    :type image_pull_policy: str
     :param annotations: non-identifying metadata you can attach to the Pod.
         Can be a large range of data, and can include characters
         that are not permitted by labels.
-    :type annotations: dict
-    :param resources: A dict containing resources requests and limits.
-        Possible keys are request_memory, request_cpu, limit_memory, limit_cpu,
-        and limit_gpu, which will be used to generate airflow.kubernetes.pod.Resources.
-        See also kubernetes.io/docs/concepts/configuration/manage-compute-resources-container
-    :type resources: k8s.V1ResourceRequirements
-    :param affinity: A dict containing a group of affinity scheduling rules.
-    :type affinity: k8s.V1Affinity
+    :param resources: resources for the launched pod.
+    :param affinity: affinity scheduling rules for the launched pod.
     :param config_file: The path to the Kubernetes config file. (templated)
         If not specified, default value is ``~/.kube/config``
-    :type config_file: str
-    :param node_selectors: A dict containing a group of scheduling rules.
-    :type node_selectors: dict
+    :param node_selector: A dict containing a group of scheduling rules.
     :param image_pull_secrets: Any image pull secrets to be given to the pod.
         If more than one secret is required, provide a
         comma separated list: secret_a,secret_b
-    :type image_pull_secrets: List[k8s.V1LocalObjectReference]
     :param service_account_name: Name of the service account
-    :type service_account_name: str
     :param is_delete_operator_pod: What to do when the pod reaches its final
-        state, or the execution is interrupted.
-        If False (default): do nothing, If True: delete the pod
-    :type is_delete_operator_pod: bool
+        state, or the execution is interrupted. If True (default), delete the
+        pod; if False, leave the pod.
     :param hostnetwork: If True enable host networking on the pod.
-    :type hostnetwork: bool
     :param tolerations: A list of kubernetes tolerations.
-    :type tolerations: List[k8s.V1Toleration]
     :param security_context: security options the pod should run with (PodSecurityContext).
-    :type security_context: dict
     :param dnspolicy: dnspolicy for the pod.
-    :type dnspolicy: str
     :param schedulername: Specify a schedulername for the pod
-    :type schedulername: str
     :param full_pod_spec: The complete podSpec
-    :type full_pod_spec: kubernetes.client.models.V1Pod
     :param init_containers: init container for the launched Pod
-    :type init_containers: list[kubernetes.client.models.V1Container]
     :param log_events_on_failure: Log the pod's events if a failure occurs
-    :type log_events_on_failure: bool
     :param do_xcom_push: If True, the content of the file
         /airflow/xcom/return.json in the container will also be pushed to an
         XCom when the container completes.
-    :type do_xcom_push: bool
     :param pod_template_file: path to pod template file (templated)
-    :type pod_template_file: str
     :param priority_class_name: priority class name for the launched Pod
-    :type priority_class_name: str
     :param termination_grace_period: Termination grace period if task killed in UI,
         defaults to kubernetes default
-    :type termination_grace_period: int
     """
 
-    template_fields: Iterable[str] = (
+    BASE_CONTAINER_NAME = 'base'
+    POD_CHECKED_KEY = 'already_checked'
+
+    template_fields: Sequence[str] = (
         'image',
         'cmds',
         'arguments',
@@ -170,16 +151,16 @@ class KubernetesPodOperator(BaseOperator):
         'labels',
         'config_file',
         'pod_template_file',
+        'namespace',
     )
 
-    # fmt: off
     def __init__(
-        # fmt: on
         self,
         *,
         namespace: Optional[str] = None,
         image: Optional[str] = None,
         name: Optional[str] = None,
+        random_name_suffix: Optional[bool] = True,
         cmds: Optional[List[str]] = None,
         arguments: Optional[List[str]] = None,
         ports: Optional[List[k8s.V1ContainerPort]] = None,
@@ -203,7 +184,7 @@ class KubernetesPodOperator(BaseOperator):
         node_selector: Optional[dict] = None,
         image_pull_secrets: Optional[List[k8s.V1LocalObjectReference]] = None,
         service_account_name: Optional[str] = None,
-        is_delete_operator_pod: bool = False,
+        is_delete_operator_pod: bool = True,
         hostnetwork: bool = False,
         tolerations: Optional[List[k8s.V1Toleration]] = None,
         security_context: Optional[Dict] = None,
@@ -215,9 +196,9 @@ class KubernetesPodOperator(BaseOperator):
         do_xcom_push: bool = False,
         pod_template_file: Optional[str] = None,
         priority_class_name: Optional[str] = None,
-        pod_runtime_info_envs: List[PodRuntimeInfoEnv] = None,
+        pod_runtime_info_envs: Optional[List[k8s.V1EnvVar]] = None,
         termination_grace_period: Optional[int] = None,
-        configmaps: Optional[str] = None,
+        configmaps: Optional[List[str]] = None,
         **kwargs,
     ) -> None:
         if kwargs.get('xcom_push') is not None:
@@ -264,8 +245,9 @@ class KubernetesPodOperator(BaseOperator):
         self.service_account_name = service_account_name
         self.is_delete_operator_pod = is_delete_operator_pod
         self.hostnetwork = hostnetwork
-        self.tolerations = [convert_toleration(toleration) for toleration in tolerations] \
-            if tolerations else []
+        self.tolerations = (
+            [convert_toleration(toleration) for toleration in tolerations] if tolerations else []
+        )
         self.security_context = security_context or {}
         self.dnspolicy = dnspolicy
         self.schedulername = schedulername
@@ -275,14 +257,15 @@ class KubernetesPodOperator(BaseOperator):
         self.priority_class_name = priority_class_name
         self.pod_template_file = pod_template_file
         self.name = self._set_name(name)
+        self.random_name_suffix = random_name_suffix
         self.termination_grace_period = termination_grace_period
-        self.client: CoreV1Api = None
-        self.pod: k8s.V1Pod = None
+        self.pod_request_obj: Optional[k8s.V1Pod] = None
+        self.pod: Optional[k8s.V1Pod] = None
 
     def _render_nested_template_fields(
         self,
         content: Any,
-        context: Dict,
+        context: 'Context',
         jinja_env: "jinja2.Environment",
         seen_oids: set,
     ) -> None:
@@ -291,27 +274,31 @@ class KubernetesPodOperator(BaseOperator):
             self._do_render_template_fields(content, ('value', 'name'), context, jinja_env, seen_oids)
             return
 
-        super()._render_nested_template_fields(
-            content,
-            context,
-            jinja_env,
-            seen_oids
-        )
+        super()._render_nested_template_fields(content, context, jinja_env, seen_oids)
 
     @staticmethod
-    def create_labels_for_pod(context) -> dict:
+    def _get_ti_pod_labels(context: Optional[dict] = None, include_try_number: bool = True) -> dict:
         """
         Generate labels for the pod to track the pod in case of Operator crash
 
         :param context: task context provided by airflow DAG
         :return: dict
         """
-        labels = {
-            'dag_id': context['dag'].dag_id,
-            'task_id': context['task'].task_id,
-            'execution_date': context['ts'],
-            'try_number': context['ti'].try_number,
-        }
+        if not context:
+            return {}
+
+        ti = context['ti']
+        run_id = context['run_id']
+
+        labels = {'dag_id': ti.dag_id, 'task_id': ti.task_id, 'run_id': run_id}
+
+        # If running on Airflow 2.3+:
+        map_index = getattr(ti, 'map_index', -1)
+        if map_index >= 0:
+            labels['map_index'] = map_index
+
+        if include_try_number:
+            labels.update(try_number=ti.try_number)
         # In the case of sub dags this is just useful
         if context['dag'].is_subdag:
             labels['parent_dag_id'] = context['dag'].parent_dag.dag_id
@@ -322,101 +309,131 @@ class KubernetesPodOperator(BaseOperator):
             labels[label_id] = safe_label
         return labels
 
-    def create_pod_launcher(self) -> Type[pod_launcher.PodLauncher]:
-        return pod_launcher.PodLauncher(kube_client=self.client, extract_xcom=self.do_xcom_push)
+    @cached_property
+    def pod_manager(self) -> PodManager:
+        return PodManager(kube_client=self.client)
 
-    def execute(self, context) -> Optional[str]:
+    @cached_property
+    def client(self) -> CoreV1Api:
+        # todo: use airflow Connection / hook to authenticate to the cluster
+        kwargs: Dict[str, Any] = dict(
+            cluster_context=self.cluster_context,
+            config_file=self.config_file,
+        )
+        if self.in_cluster is not None:
+            kwargs.update(in_cluster=self.in_cluster)
+        return kube_client.get_kube_client(**kwargs)
+
+    def find_pod(self, namespace, context) -> Optional[k8s.V1Pod]:
+        """Returns an already-running pod for this task instance if one exists."""
+        label_selector = self._build_find_pod_label_selector(context)
+        pod_list = self.client.list_namespaced_pod(
+            namespace=namespace,
+            label_selector=label_selector,
+        ).items
+
+        pod = None
+        num_pods = len(pod_list)
+        if num_pods > 1:
+            raise AirflowException(f'More than one pod running with labels {label_selector}')
+        elif num_pods == 1:
+            pod = pod_list[0]
+            self.log.info("Found matching pod %s with labels %s", pod.metadata.name, pod.metadata.labels)
+            self.log.info("`try_number` of task_instance: %s", context['ti'].try_number)
+            self.log.info("`try_number` of pod: %s", pod.metadata.labels['try_number'])
+        return pod
+
+    def get_or_create_pod(self, pod_request_obj: k8s.V1Pod, context):
+        if self.reattach_on_restart:
+            pod = self.find_pod(self.namespace or pod_request_obj.metadata.namespace, context=context)
+            if pod:
+                return pod
+        self.log.debug("Starting pod:\n%s", yaml.safe_dump(pod_request_obj.to_dict()))
+        self.pod_manager.create_pod(pod=pod_request_obj)
+        return pod_request_obj
+
+    def await_pod_start(self, pod):
         try:
-            if self.in_cluster is not None:
-                client = kube_client.get_kube_client(
-                    in_cluster=self.in_cluster,
-                    cluster_context=self.cluster_context,
-                    config_file=self.config_file,
+            self.pod_manager.await_pod_start(pod=pod, startup_timeout=self.startup_timeout_seconds)
+        except PodLaunchFailedException:
+            if self.log_events_on_failure:
+                for event in self.pod_manager.read_pod_events(pod).items:
+                    self.log.error("Pod Event: %s - %s", event.reason, event.message)
+            raise
+
+    def extract_xcom(self, pod):
+        """Retrieves xcom value and kills xcom sidecar container"""
+        result = self.pod_manager.extract_xcom(pod)
+        self.log.info("xcom result: \n%s", result)
+        return json.loads(result)
+
+    def execute(self, context: 'Context'):
+        remote_pod = None
+        try:
+            self.pod_request_obj = self.build_pod_request_obj(context)
+            self.pod = self.get_or_create_pod(  # must set `self.pod` for `on_kill`
+                pod_request_obj=self.pod_request_obj,
+                context=context,
+            )
+            self.await_pod_start(pod=self.pod)
+
+            if self.get_logs:
+                self.pod_manager.fetch_container_logs(
+                    pod=self.pod,
+                    container_name=self.BASE_CONTAINER_NAME,
+                    follow=True,
                 )
             else:
-                client = kube_client.get_kube_client(
-                    cluster_context=self.cluster_context, config_file=self.config_file
+                self.pod_manager.await_container_completion(
+                    pod=self.pod, container_name=self.BASE_CONTAINER_NAME
                 )
 
-            self.client = client
-
-            self.pod = self.create_pod_request_obj()
-            self.namespace = self.pod.metadata.namespace
-
-            # Add combination of labels to uniquely identify a running pod
-            labels = self.create_labels_for_pod(context)
-
-            label_selector = self._get_pod_identifying_label_string(labels)
-
-            pod_list = self.client.list_namespaced_pod(self.namespace, label_selector=label_selector)
-
-            if len(pod_list.items) > 1 and self.reattach_on_restart:
-                raise AirflowException(
-                    f'More than one pod running with labels: {label_selector}'
-                )
-
-            launcher = self.create_pod_launcher()
-
-            if len(pod_list.items) == 1:
-                try_numbers_match = self._try_numbers_match(context, pod_list.items[0])
-                final_state, remote_pod, result = self.handle_pod_overlap(
-                    labels, try_numbers_match, launcher, pod_list.items[0]
-                )
-            else:
-                self.log.info("creating pod with labels %s and launcher %s", labels, launcher)
-                final_state, remote_pod, result = self.create_new_pod_for_operator(labels, launcher)
-            if final_state != State.SUCCESS:
-                raise AirflowException(f'Pod {self.pod.metadata.name} returned a failure: {remote_pod}')
-            context['task_instance'].xcom_push(key='pod_name', value=self.pod.metadata.name)
-            context['task_instance'].xcom_push(key='pod_namespace', value=self.namespace)
+            if self.do_xcom_push:
+                result = self.extract_xcom(pod=self.pod)
+            remote_pod = self.pod_manager.await_pod_completion(self.pod)
+        finally:
+            self.cleanup(
+                pod=self.pod or self.pod_request_obj,
+                remote_pod=remote_pod,
+            )
+        ti = context['ti']
+        ti.xcom_push(key='pod_name', value=self.pod.metadata.name)
+        ti.xcom_push(key='pod_namespace', value=self.pod.metadata.namespace)
+        if self.do_xcom_push:
             return result
-        except AirflowException as ex:
-            raise AirflowException(f'Pod Launching failed: {ex}')
 
-    def handle_pod_overlap(
-        self, labels: dict, try_numbers_match: bool, launcher: Any, pod: k8s.V1Pod
-    ) -> Tuple[State, k8s.V1Pod, Optional[str]]:
-        """
-
-        In cases where the Scheduler restarts while a KubernetesPodOperator task is running,
-        this function will either continue to monitor the existing pod or launch a new pod
-        based on the `reattach_on_restart` parameter.
-
-        :param labels: labels used to determine if a pod is repeated
-        :type labels: dict
-        :param try_numbers_match: do the try numbers match? Only needed for logging purposes
-        :type try_numbers_match: bool
-        :param launcher: PodLauncher
-        :param pod: Pod found with matching labels
-        """
-        if try_numbers_match:
-            log_line = f"found a running pod with labels {labels} and the same try_number."
+    def cleanup(self, pod: k8s.V1Pod, remote_pod: k8s.V1Pod):
+        pod_phase = remote_pod.status.phase if hasattr(remote_pod, 'status') else None
+        if not self.is_delete_operator_pod:
+            with _suppress(Exception):
+                self.patch_already_checked(pod)
+        if pod_phase != PodPhase.SUCCEEDED:
+            if self.log_events_on_failure:
+                with _suppress(Exception):
+                    for event in self.pod_manager.read_pod_events(pod).items:
+                        self.log.error("Pod Event: %s - %s", event.reason, event.message)
+            with _suppress(Exception):
+                self.process_pod_deletion(pod)
+            error_message = get_container_termination_message(remote_pod, self.BASE_CONTAINER_NAME)
+            error_message = "\n" + error_message if error_message else ""
+            raise AirflowException(
+                f'Pod {pod and pod.metadata.name} returned a failure:{error_message}\n{remote_pod}'
+            )
         else:
-            log_line = f"found a running pod with labels {labels} but a different try_number."
+            with _suppress(Exception):
+                self.process_pod_deletion(pod)
 
-        # In case of failed pods, should reattach the first time, but only once
-        # as the task will have already failed.
-        if self.reattach_on_restart and not pod.metadata.labels.get("already_checked"):
-            log_line += " Will attach to this pod and monitor instead of starting new one"
-            self.log.info(log_line)
-            self.pod = pod
-            final_state, remote_pod, result = self.monitor_launched_pod(launcher, pod)
+    def process_pod_deletion(self, pod):
+        if self.is_delete_operator_pod:
+            self.log.info("Deleting pod: %s", pod.metadata.name)
+            self.pod_manager.delete_pod(pod)
         else:
-            log_line += f"creating pod with labels {labels} and launcher {launcher}"
-            self.log.info(log_line)
-            final_state, remote_pod, result = self.create_new_pod_for_operator(labels, launcher)
-        return final_state, remote_pod, result
+            self.log.info("skipping deleting pod: %s", pod.metadata.name)
 
-    @staticmethod
-    def _get_pod_identifying_label_string(labels) -> str:
-        label_strings = [
-            f'{label_id}={label}' for label_id, label in sorted(labels.items()) if label_id != 'try_number'
-        ]
-        return ','.join(label_strings) + ',already_checked!=True'
-
-    @staticmethod
-    def _try_numbers_match(context, pod) -> bool:
-        return pod.metadata.labels['try_number'] == context['ti'].try_number
+    def _build_find_pod_label_selector(self, context: Optional[dict] = None) -> str:
+        labels = self._get_ti_pod_labels(context, include_try_number=False)
+        label_strings = [f'{label_id}={label}' for label_id, label in sorted(labels.items())]
+        return ','.join(label_strings) + f',{self.POD_CHECKED_KEY}!=True'
 
     def _set_name(self, name):
         if name is None:
@@ -425,13 +442,31 @@ class KubernetesPodOperator(BaseOperator):
             raise AirflowException("`name` is required unless `pod_template_file` or `full_pod_spec` is set")
 
         validate_key(name, max_length=220)
-        return re.sub(r'[^a-z0-9.-]+', '-', name.lower())
+        return re.sub(r'[^a-z0-9-]+', '-', name.lower())
 
-    def create_pod_request_obj(self) -> k8s.V1Pod:
+    def patch_already_checked(self, pod: k8s.V1Pod):
+        """Add an "already checked" annotation to ensure we don't reattach on retries"""
+        pod.metadata.labels[self.POD_CHECKED_KEY] = "True"
+        body = PodGenerator.serialize_pod(pod)
+        self.client.patch_namespaced_pod(pod.metadata.name, pod.metadata.namespace, body)
+
+    def on_kill(self) -> None:
+        if self.pod:
+            pod = self.pod
+            kwargs = dict(
+                name=pod.metadata.name,
+                namespace=pod.metadata.namespace,
+            )
+            if self.termination_grace_period is not None:
+                kwargs.update(grace_period_seconds=self.termination_grace_period)
+            self.client.delete_namespaced_pod(**kwargs)
+
+    def build_pod_request_obj(self, context=None):
         """
-        Creates a V1Pod based on user parameters. Note that a `pod` or `pod_template_file`
-        will supersede all other values.
+        Returns V1Pod object based on pod template file, full pod spec, and other operator parameters.
 
+        The V1Pod attributes are derived (in order of precedence) from operator params, full pod spec, pod
+        template file.
         """
         self.log.debug("Creating pod for KubernetesPodOperator task %s", self.task_id)
         if self.pod_template_file:
@@ -450,7 +485,7 @@ class KubernetesPodOperator(BaseOperator):
             metadata=k8s.V1ObjectMeta(
                 namespace=self.namespace,
                 labels=self.labels,
-                name=PodGenerator.make_unique_pod_id(self.name),
+                name=self.name,
                 annotations=self.annotations,
             ),
             spec=k8s.V1PodSpec(
@@ -461,7 +496,7 @@ class KubernetesPodOperator(BaseOperator):
                 containers=[
                     k8s.V1Container(
                         image=self.image,
-                        name="base",
+                        name=self.BASE_CONTAINER_NAME,
                         command=self.cmds,
                         ports=self.ports,
                         image_pull_policy=self.image_pull_policy,
@@ -486,89 +521,62 @@ class KubernetesPodOperator(BaseOperator):
 
         pod = PodGenerator.reconcile_pods(pod_template, pod)
 
+        if self.random_name_suffix:
+            pod.metadata.name = PodGenerator.make_unique_pod_id(pod.metadata.name)
+
         for secret in self.secrets:
             self.log.debug("Adding secret to task %s", self.task_id)
             pod = secret.attach_to_pod(pod)
         if self.do_xcom_push:
             self.log.debug("Adding xcom sidecar to task %s", self.task_id)
             pod = xcom_sidecar.add_xcom_sidecar(pod)
-        return pod
 
-    def create_new_pod_for_operator(self, labels, launcher) -> Tuple[State, k8s.V1Pod, Optional[str]]:
-        """
-        Creates a new pod and monitors for duration of task
-
-        :param labels: labels used to track pod
-        :param launcher: pod launcher that will manage launching and monitoring pods
-        :return:
-        """
-        self.log.debug(
-            "Adding KubernetesPodOperator labels to pod before launch for task %s", self.task_id
-        )
+        labels = self._get_ti_pod_labels(context)
+        self.log.info("Creating pod %s with labels: %s", pod.metadata.name, labels)
 
         # Merge Pod Identifying labels with labels passed to operator
-        self.pod.metadata.labels.update(labels)
+        pod.metadata.labels.update(labels)
         # Add Airflow Version to the label
         # And a label to identify that pod is launched by KubernetesPodOperator
-        self.pod.metadata.labels.update(
+        pod.metadata.labels.update(
             {
                 'airflow_version': airflow_version.replace('+', '-'),
                 'kubernetes_pod_operator': 'True',
             }
         )
+        pod_mutation_hook(pod)
+        return pod
 
-        self.log.debug("Starting pod:\n%s", yaml.safe_dump(self.pod.to_dict()))
-        final_state = None
-        try:
-            launcher.start_pod(self.pod, startup_timeout=self.startup_timeout_seconds)
-            final_state, remote_pod, result = launcher.monitor_pod(pod=self.pod, get_logs=self.get_logs)
-        except AirflowException:
-            if self.log_events_on_failure:
-                for event in launcher.read_pod_events(self.pod).items:
-                    self.log.error("Pod Event: %s - %s", event.reason, event.message)
-            raise
-        finally:
-            if self.is_delete_operator_pod:
-                self.log.debug("Deleting pod for task %s", self.task_id)
-                launcher.delete_pod(self.pod)
-            elif final_state != State.SUCCESS:
-                self.patch_already_checked(self.pod)
-        return final_state, remote_pod, result
-
-    def patch_already_checked(self, pod: k8s.V1Pod):
-        """Add an "already tried annotation to ensure we only retry once"""
-        pod.metadata.labels["already_checked"] = "True"
-        body = PodGenerator.serialize_pod(pod)
-        self.client.patch_namespaced_pod(pod.metadata.name, pod.metadata.namespace, body)
-
-    def monitor_launched_pod(self, launcher, pod) -> Tuple[State, Optional[str]]:
+    def dry_run(self) -> None:
         """
-        Monitors a pod to completion that was created by a previous KubernetesPodOperator
-
-        :param launcher: pod launcher that will manage launching and monitoring pods
-        :param pod: podspec used to find pod using k8s API
-        :return:
+        Prints out the pod definition that would be created by this operator.
+        Does not include labels specific to the task instance (since there isn't
+        one in a dry_run) and excludes all empty elements.
         """
-        try:
-            (final_state, remote_pod, result) = launcher.monitor_pod(pod, get_logs=self.get_logs)
-        finally:
-            if self.is_delete_operator_pod:
-                launcher.delete_pod(pod)
-        if final_state != State.SUCCESS:
-            if self.log_events_on_failure:
-                for event in launcher.read_pod_events(pod).items:
-                    self.log.error("Pod Event: %s - %s", event.reason, event.message)
-            if not self.is_delete_operator_pod:
-                self.patch_already_checked(pod)
-            raise AirflowException(f'Pod returned a failure: {final_state}')
-        return final_state, remote_pod, result
+        pod = self.build_pod_request_obj()
+        print(yaml.dump(prune_dict(pod.to_dict(), mode='strict')))
 
-    def on_kill(self) -> None:
-        if self.pod:
-            pod: k8s.V1Pod = self.pod
-            namespace = pod.metadata.namespace
-            name = pod.metadata.name
-            kwargs = {}
-            if self.termination_grace_period is not None:
-                kwargs = {"grace_period_seconds": self.termination_grace_period}
-            self.client.delete_namespaced_pod(name=name, namespace=namespace, **kwargs)
+
+class _suppress(AbstractContextManager):
+    """
+    This behaves the same as ``contextlib.suppress`` but logs the suppressed
+    exceptions as errors with traceback.
+
+    The caught exception is also stored on the context manager instance under
+    attribute ``exception``.
+    """
+
+    def __init__(self, *exceptions):
+        self._exceptions = exceptions
+        self.exception = None
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exctype, excinst, exctb):
+        caught_error = exctype is not None and issubclass(exctype, self._exceptions)
+        if caught_error:
+            self.exception = excinst
+            logger = logging.getLogger()
+            logger.error(str(excinst), exc_info=True)
+        return caught_error
