@@ -15,7 +15,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from typing import Any, Callable, Dict, List, Optional
+from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional
 
 from datadog import api
 
@@ -23,6 +23,9 @@ from airflow.exceptions import AirflowException
 from airflow.providers.datadog.hooks.datadog import DatadogHook
 from airflow.sensors.base import BaseSensorOperator
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class DatadogSensor(BaseSensorOperator):
     """
@@ -33,18 +36,12 @@ class DatadogSensor(BaseSensorOperator):
     Airflow runs.
 
     :param datadog_conn_id: The connection to datadog, containing metadata for api keys.
-    :type datadog_conn_id: str
     :param from_seconds_ago: POSIX timestamp start (default 3600).
-    :type from_seconds_ago: int
     :param up_to_seconds_from_now: POSIX timestamp end (default 0).
-    :type up_to_seconds_from_now: int
     :param priority: Priority of your events, either low or normal.
-    :type priority: Optional[str]
     :param sources: A comma separated list indicating what tags, if any,
         should be used to filter the list of monitors by scope
-    :type sources: Optional[str]
     :param tags: Get datadog events from specific sources.
-    :type tags: Optional[List[str]]
     :param response_check: A check against the ‘requests’ response object. The callable takes
         the response object as the first positional argument and optionally any number of
         keyword arguments available in the context dictionary. It should return True for
@@ -75,7 +72,7 @@ class DatadogSensor(BaseSensorOperator):
         self.tags = tags
         self.response_check = response_check
 
-    def poke(self, context: Dict[str, Any]) -> bool:
+    def poke(self, context: 'Context') -> bool:
         # This instantiates the hook, but doesn't need it further,
         # because the API authenticates globally (unfortunately),
         # but for airflow this shouldn't matter too much, because each
